@@ -1,25 +1,12 @@
 ##################################################################
-# A module with simple functions
+# Module for ABI Monitor with basic functions
 #
-# Copyright (C) 2015-2017 Andrey Ponomarenko's ABI Laboratory
+# Copyright (C) 2015 Andrey Ponomarenko's ABI Laboratory
 #
 # Written by Andrey Ponomarenko
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License or the GNU Lesser
-# General Public License as published by the Free Software Foundation.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# and the GNU Lesser General Public License along with this program.
-# If not, see <http://www.gnu.org/licenses/>.
 ##################################################################
 use strict;
-use POSIX qw(strftime);
 use Fcntl;
 
 sub findFiles(@)
@@ -114,6 +101,39 @@ sub writeFile($$)
     close(FILE);
 }
 
+sub composeHTML_Head($$$$$)
+{
+    my ($Title, $Keywords, $Description, $TopDir, $Styles, $Scripts) = @_;
+    
+    my $CommonStyles = "common.css";
+    
+    if($Styles)
+    {
+        $CommonStyles = "<link rel=\"stylesheet\" type=\"text/css\" href=\"$TopDir/css/$CommonStyles\" />";
+        $Styles = "<link rel=\"stylesheet\" type=\"text/css\" href=\"$TopDir/css/$Styles\" />";
+    }
+    
+    if($Scripts) {
+        $Scripts = "<script type=\"text/javascript\" src=\"$TopDir/js/$Scripts\"></script>";
+    }
+    
+    return "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">
+    <html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">
+    <head>
+    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />
+    <meta name=\"keywords\" content=\"$Keywords\" />
+    <meta name=\"description\" content=\"$Description\" />
+    $CommonStyles
+    $Styles
+    $Scripts
+    
+    <title>
+        $Title
+    </title>
+    
+    </head>\n";
+}
+
 sub extractPackage($$)
 {
     my ($Path, $OutDir) = @_;
@@ -164,9 +184,10 @@ sub cmpVersions_S($$)
     return 0;
 }
 
-sub checkCmd($)
+sub check_Cmd($)
 {
     my $Cmd = $_[0];
+    return "" if(not $Cmd);
     
     foreach my $Path (sort {length($a)<=>length($b)} split(/:/, $ENV{"PATH"}))
     {
@@ -178,61 +199,4 @@ sub checkCmd($)
     return 0;
 }
 
-sub getMajor($$)
-{
-    my ($V, $L) = @_;
-    
-    $V=~s/[\-_]/./g;
-    
-    my @P = split(/\./, $V);
-    
-    if($#P>=$L) {
-        return join(".", splice(@P, 0, $L));
-    }
-    return $V;
-}
-
-sub formatNum($)
-{
-    my $Num = $_[0];
-    
-    if($Num=~/\A(\d+\.\d\d)/) {
-        return $1;
-    }
-    
-    return $Num
-}
-
-sub fNum($)
-{
-    my $N = $_[0];
-    if(length($N)==1) {
-        return "0".$N;
-    }
-    return $N;
-}
-
-sub getDate()
-{
-    my ($D, $M, $Y) = (localtime)[3, 4, 5];
-    return (1900+$Y)."-".fNum($M+1)."-".fNum($D);
-}
-
-sub getRssDate($)
-{
-    my $Date = $_[0];
-    
-    my ($Year, $Mon, $Mday, $Hour, $Min) = split(/[\s\-:]+/, $Date);
-    return strftime('%a, %d %b %Y %T', 0, $Min, $Hour, $Mday, $Mon-1, $Year-1900)." ".strftime('%z', localtime);
-}
-
-sub getS($)
-{
-    if($_[0]>1) {
-        return "s";
-    }
-    
-    return "";
-}
-
 return 1;
